Trace extraction
================

Now the intensity traces can be extracted at the found positions.

.. code-block:: python

    file_selection.extract_traces()

The intensity and corresponding FRET traces are added to the existing .nc file.
